Minor pottering
--- diff/drivers/md/dm-latency-ps.c	2003-12-29 10:15:37.000000000 +0000
+++ source/drivers/md/dm-latency-ps.c	2003-12-29 10:16:02.000000000 +0000
@@ -11,12 +11,12 @@
  *	Returns path with minimum latency in the same priority group
  *	of the one handed in unless failed.
  *      If all paths in the priority group got failed, returns the first
- *	operational one in the group with the next lower prioity.
- *
+ *	operational one in the group with the next lower priority.
  */
 
 #include "dm.h"
 #include "dm-path-selector.h"
+
 #include <linux/slab.h>
 
 /* Path selector context */
@@ -49,7 +49,7 @@
 };
 
 /* Allocate latency context */
-static struct latency_c *_alloc_latency_c(void)
+static struct latency_c *alloc_latency_c(void)
 {
 	struct latency_c *lc = kmalloc(sizeof(*lc), GFP_KERNEL);
 
@@ -64,7 +64,7 @@
 }
 
 /* Allocate path context */
-static struct path_c *_alloc_path_c(void)
+static struct path_c *alloc_path_c(void)
 {
 	struct path_c *pc = kmalloc(sizeof(*pc), GFP_KERNEL);
 
@@ -88,14 +88,13 @@
 		return -EINVAL;
 	}
 
-	lc = _alloc_latency_c();
+	lc = alloc_latency_c();
 	if (!lc) {
 		*error = "latency path selector: Error allocating context";
 		return -ENOMEM;
 	}
 
 	ps->context = (void *) lc;
-
 	return 0;
 }
 
@@ -155,7 +154,7 @@
 		return NULL;
 	}
 
-	pc = _alloc_path_c();
+	pc = alloc_path_c();
 	if (!pc) {
 		*error = "latency path selector: Error allocating path context";
 		return NULL;
@@ -265,12 +264,12 @@
 
 /* Path end IO */
 static void latency_endio(struct path_selector *ps,
-			       struct buffer_head *bh,
-			       int rw, int error,
-			       struct path_info *path_context)
+			  struct buffer_head *bh,
+			  int rw, int error,
+			  struct path_info *path_context)
 {
 	unsigned long flags;
-	typeof(jiffies) j;
+	jiffy_t j;
 	struct path_c *path = path_context->ptr;
 
 	BUG_ON(!path);
--- diff/drivers/md/dm-mpath.c	2003-12-29 10:15:56.000000000 +0000
+++ source/drivers/md/dm-mpath.c	2003-12-29 10:16:02.000000000 +0000
@@ -77,12 +77,12 @@
 	int reactivation_interval;	/* Automatic reactivation interval */
 	int fail_max;			/* Maximum failures allowed */
 
-	jiffy_t io_jiffies;	/* Jiffies of last IO queued */
+	jiffy_t io_jiffies;		/* Jiffies of last IO queued */
 	atomic_t fail;			/* actual failure count vs. fail_max */
 	atomic_t fail_total;		/* Total failures on this path */
 
-	void *ps_private;	   /* Opaque pointer to path selector object */
-	unsigned long test_sector; /* Path scrubbing sector */
+	void *ps_private;	   	/* Opaque pointer to path selector object */
+	unsigned long test_sector; 	/* Path scrubbing sector */
 };
 
 /*
@@ -317,7 +317,7 @@
 
 /*-----------------------------------------------------------------
  * The multipath daemon is responsible for periodically
- * retestings failed paths.
+ * retestings failed paths and resubmitting failed ios.
  *---------------------------------------------------------------*/
 static struct dm_daemon _kmultipathd;
 
@@ -693,9 +693,9 @@
 {
 	struct multipath_c *mc = (struct multipath_c *) ti->private;
 
-	_wait_for_scrub_ios(mc);
-	_remove_mc_job(mc);
-	_free_context(mc);
+	wait_for_scrub_ios(mc);
+	remove_mc_job(mc);
+	free_context(mc);
 }
 
 static inline void map(struct multipath_io *io, struct path *path)
